@@ -11,6 +11,7 @@
 
 
 #include "dasher.h"
+#include "dasher_lock_dialogue.h"
 #ifdef WITH_MAEMO
 #include "dasher_maemo_helper.h"
 #endif
@@ -102,6 +103,8 @@ static gboolean dasher_main_speed_changed(DasherMain *pSelf);
 static void dasher_main_populate_alphabet_combo(DasherMain *pSelf);
 void dasher_main_build_context_menu(DasherMain *pSelf);
 
+gboolean grab_focus();
+
 // Private functions not in class
 extern "C" gboolean take_real_focus(GtkWidget *widget, GdkEventFocus *event, gpointer user_data);
 extern "C" gboolean edit_key_press(GtkWidget *widget, GdkEventKey *event, gpointer user_data);
@@ -777,6 +780,8 @@ void dasher_main_setup_window_style(DasherMain *pSelf, bool bTopMost) {
   }
 
   gtk_window_set_keep_above(GTK_WINDOW(pPrivate->pMainWindow), pPrivate->bTopMost);
+  dasher_lock_dialogue_set_transient(GTK_WINDOW(pPrivate->pMainWindow));
+  
 
 #ifdef WITH_MAEMO
   gtk_window_set_accept_focus(GTK_WINDOW(pPrivate->pMainWindow), false);
@@ -785,6 +790,9 @@ void dasher_main_setup_window_style(DasherMain *pSelf, bool bTopMost) {
   gtk_window_set_accept_focus(GTK_WINDOW(pPrivate->pMainWindow), !(pPrivate->bTopMost));
   gtk_window_set_focus_on_map(GTK_WINDOW(pPrivate->pMainWindow), !(pPrivate->bTopMost));
 #endif
+
+  
+  grab_focus();
 }
 
 
@@ -1114,6 +1122,11 @@ extern "C" bool focus_in_event(GtkWidget *widget, GdkEventFocus *event, gpointer
   return grab_focus();
 }
 
+extern "C" bool edit_focus_in_event(GtkWidget *widget, GdkEventFocus *event, gpointer data) {
+  return true;
+}
+
+
 // TODO: Next three handlers should just forward into class
 extern "C" gboolean take_real_focus(GtkWidget *widget, GdkEventFocus *event, gpointer user_data) {
   g_bForwardKeyboard = false;
