@@ -32,13 +32,13 @@ CPrefs::CPrefs(HWND hParent, CDasher *pDasher, CAppSettings *pAppSettings)
   m_pViewPage = new CViewPage(hParent, pDasher, pAppSettings);
   m_pAdvancedPage = new CAdvancedPage(hParent, pDasher, pAppSettings);
   m_pLMPage = new CLMPage(hParent, pDasher, pAppSettings);
-  m_pSocketPage = new CSocketPage(hParent, pDasher, pAppSettings);
+//  m_pSocketPage = new CSocketPage(hParent, pDasher, pAppSettings);
 
     PROPSHEETPAGE psp[6];
     PROPSHEETHEADER psh;
 
     psp[0].dwSize = sizeof(PROPSHEETPAGE);
-    psp[0].dwFlags = PSP_USEICONID | PSP_USETITLE;
+    psp[0].dwFlags = PSP_USEICONID | PSP_USETITLE | PSP_PREMATURE;
     psp[0].hInstance = WinHelper::hInstApp;
     psp[0].pszTemplate = MAKEINTRESOURCE(IDD_ALPHABETPAGE);
     psp[0].pszIcon = NULL;
@@ -58,7 +58,7 @@ CPrefs::CPrefs(HWND hParent, CDasher *pDasher, CAppSettings *pAppSettings)
     psp[1].pfnCallback = NULL;*/
 
     psp[1].dwSize = sizeof(PROPSHEETPAGE);
-    psp[1].dwFlags = PSP_USEICONID | PSP_USETITLE;
+    psp[1].dwFlags = PSP_USEICONID | PSP_USETITLE | PSP_PREMATURE;
     psp[1].hInstance = WinHelper::hInstApp;
     psp[1].pszTemplate = MAKEINTRESOURCE(IDD_CONTROLPAGE);
     psp[1].pszIcon = NULL;
@@ -68,7 +68,7 @@ CPrefs::CPrefs(HWND hParent, CDasher *pDasher, CAppSettings *pAppSettings)
     psp[1].pfnCallback = NULL;
 
     psp[2].dwSize = sizeof(PROPSHEETPAGE);
-    psp[2].dwFlags = PSP_USEICONID | PSP_USETITLE;
+    psp[2].dwFlags = PSP_USEICONID | PSP_USETITLE | PSP_PREMATURE;
     psp[2].hInstance = WinHelper::hInstApp;
     psp[2].pszTemplate = MAKEINTRESOURCE(IDD_VIEWPAGE);
     psp[2].pszIcon = NULL;
@@ -78,7 +78,7 @@ CPrefs::CPrefs(HWND hParent, CDasher *pDasher, CAppSettings *pAppSettings)
     psp[2].pfnCallback = NULL;
 
     psp[3].dwSize = sizeof(PROPSHEETPAGE);
-    psp[3].dwFlags = PSP_USEICONID | PSP_USETITLE;
+    psp[3].dwFlags = PSP_USEICONID | PSP_USETITLE | PSP_PREMATURE;
     psp[3].hInstance = WinHelper::hInstApp;
     psp[3].pszTemplate = MAKEINTRESOURCE(IDD_LMPAGE);
     psp[3].pszIcon = NULL;
@@ -88,7 +88,7 @@ CPrefs::CPrefs(HWND hParent, CDasher *pDasher, CAppSettings *pAppSettings)
     psp[3].pfnCallback = NULL;
 
     psp[4].dwSize = sizeof(PROPSHEETPAGE);
-    psp[4].dwFlags = PSP_USEICONID | PSP_USETITLE;
+    psp[4].dwFlags = PSP_USEICONID | PSP_USETITLE | PSP_PREMATURE;
     psp[4].hInstance = WinHelper::hInstApp;
     psp[4].pszTemplate = MAKEINTRESOURCE(IDD_MISCPAGE);
     psp[4].pszIcon = NULL;
@@ -97,15 +97,15 @@ CPrefs::CPrefs(HWND hParent, CDasher *pDasher, CAppSettings *pAppSettings)
     psp[4].lParam = (LPARAM) m_pAdvancedPage;
     psp[4].pfnCallback = NULL;
 
-    psp[5].dwSize = sizeof(PROPSHEETPAGE);
-    psp[5].dwFlags = PSP_USEICONID | PSP_USETITLE;
-    psp[5].hInstance = WinHelper::hInstApp;
-    psp[5].pszTemplate = MAKEINTRESOURCE(IDD_SOCKET);
-    psp[5].pszIcon = NULL;
-    psp[5].pfnDlgProc = (DLGPROC) WinWrapMap::PSWndProc;
-    psp[5].pszTitle =  MAKEINTRESOURCE(IDS_PREFS_SOCKET);
-    psp[5].lParam = (LPARAM) m_pSocketPage;
-    psp[5].pfnCallback = NULL;
+    //psp[5].dwSize = sizeof(PROPSHEETPAGE);
+    //psp[5].dwFlags = PSP_USEICONID | PSP_USETITLE | PSP_PREMATURE;
+    //psp[5].hInstance = WinHelper::hInstApp;
+    //psp[5].pszTemplate = MAKEINTRESOURCE(IDD_SOCKET);
+    //psp[5].pszIcon = NULL;
+    //psp[5].pfnDlgProc = (DLGPROC) WinWrapMap::PSWndProc;
+    //psp[5].pszTitle =  MAKEINTRESOURCE(IDS_PREFS_SOCKET);
+    //psp[5].lParam = (LPARAM) m_pSocketPage;
+    //psp[5].pfnCallback = NULL;
     
     psh.dwSize = sizeof(PROPSHEETHEADER);
     psh.dwFlags = PSH_USEICONID | PSH_PROPSHEETPAGE;
@@ -118,13 +118,16 @@ CPrefs::CPrefs(HWND hParent, CDasher *pDasher, CAppSettings *pAppSettings)
     psh.nStartPage = 0;
     psh.ppsp = (LPCPROPSHEETPAGE) &psp;
     psh.pfnCallback = NULL;
-    PropertySheet(&psh);
+   
 //    return;
 
 
  // DialogBoxParam(WinHelper::hInstApp, (LPCTSTR) IDD_PREFS, hP
     //arent, (DLGPROC) WinWrapMap::WndProc, (LPARAM) this);
-  PopulateWidgets();
+   PropertySheet(&psh);
+
+   PopulateWidgets();
+  
 }
 
 CPrefs::~CPrefs()
@@ -153,10 +156,10 @@ CPrefs::~CPrefs()
     delete m_pLMPage;
     m_pLMPage  = NULL;
   }
-  if (m_pSocketPage != NULL) {
+  /*if (m_pSocketPage != NULL) {
     delete m_pSocketPage;
     m_pSocketPage  = NULL;
-  }
+  }*/
 }
 
 
